@@ -3,14 +3,14 @@ import math
 import ufl
 from dolfin import *
 
-dolfin_set("form compiler", "sfc")
+parameters["form_compiler"]["name"]= "sfc"
 
-class Source(Function): 
+class Source(Expression): 
     def eval(self, values, x): 
         values[0] = -2 + math.exp(x[0]*x[0]) 
 
 
-class Solution(Function): 
+class Solution(Expression): 
     def eval(self, values, x): 
         values[0] = x[0]*x[0] 
 
@@ -34,7 +34,9 @@ v = TestFunction(X)
 u = TrialFunction(X)
 
 # Source term 
-source = Source(X)
+source = Source()
+s = Function(X)
+s.interpolate(source)
 
 # Forms
 F = inner(grad(U),grad(v))*dx + ufl.exp(U)*v*dx  
@@ -47,7 +49,7 @@ sol = project(solution,X)
 
 # Solve nonlinear variational problem
 dirichlet_boundary = DirichletBoundary()
-bc = DirichletBC(X, solution, dirichlet_boundary)
+bc = DirichletBC(X, sol, dirichlet_boundary)
 #problem = VariationalProblem(J, F, bc, nonlinear=True)
 
 problem = VariationalProblem(J, F, bc, nonlinear=True)
