@@ -2,14 +2,14 @@
 import math 
 from dolfin import *
 
-dolfin_set("form compiler", "sfc")
+parameters["form_compiler"]["name"]= "sfc"
 
-class Source(Function): 
+class Source(Expression): 
     def eval(self, values, x): 
         values[0] = -1.0+((0.5)*x[0]+(0.5)*x[1])**6
 
 
-class Solution(Function): 
+class Solution(Expression): 
     def eval(self, values, x): 
         values[0] = (0.5*(x[0] + x[1]))**2     
 
@@ -34,7 +34,7 @@ v = TestFunction(X)
 u = TrialFunction(X)
 
 # Source term 
-source = Source(X)
+source = Source()
 
 # Forms
 L = inner(grad(U),grad(U))*dx + U**P*dx + source*U*dx 
