@@ -1,12 +1,10 @@
 
-import math 
 from dolfin import *
 
-dolfin_set("form compiler", "sfc")
+parameters["form_compiler"]["name"]= "sfc"
 
-
-
-class BoundaryFunction(Function): 
+class BoundaryFunction(Expression): 
+    def dim(self): return 2
     def eval(self, values, x): 
         values[0] = (0.5*(x[0] + x[1]))**2     
         values[1] = (1-0.5*(x[0] + x[1]))**2  
@@ -22,14 +20,14 @@ P = 5
 mesh = UnitSquare(N,N)
 
 # Function spaces
-X = VectorFunctionSpace(mesh, 'CG', 1)
+V = VectorFunctionSpace(mesh, "CG", 1)
 
 # BoundaryFunction function 
-U = Function(X)
+U = Function(V)
 
 # Basis functions 
-v = TestFunction(X)
-u = TrialFunction(X)
+v = TestFunction(V)
+u = TrialFunction(V)
 
 # Forms
 L = inner(grad(U),grad(U))*dx + dot(U,U)**P*dx  
@@ -37,12 +35,12 @@ F = derivative(L, U, v)
 J = derivative(F, U, u)
 
 # start vector 
-boundary_function = BoundaryFunction(X)
-x0 = project(boundary_function,X)
+boundary_function = BoundaryFunction(V)
+x0 = project(boundary_function,V)
 
 # Solve nonlinear variational problem
 dirichlet_boundary = DirichletBoundary()
-bc = DirichletBC(X, boundary_function, dirichlet_boundary)
+bc = DirichletBC(V, boundary_function, dirichlet_boundary)
 #problem = VariationalProblem(J, F, bc, nonlinear=True)
 
 problem = VariationalProblem(J, F, bc, nonlinear=True)
