@@ -19,7 +19,7 @@ __license__  = "GNU LGPL Version 2.1"
 
 from dolfin import *
 
-dolfin_set("form compiler", "sfc")
+parameters["form_compiler"]["name"] = "sfc"
 
 
 # Create mesh and function space
@@ -34,14 +34,14 @@ class DirichletBoundary(SubDomain):
 # Define variational problem
 v = TestFunction(V)
 u = TrialFunction(V)
-f = Function(V, "9.0*pi*pi*sin(3.0*pi*x[0])")
-g = Function(V, "3.0*pi*cos(3.0*pi*x[0])")
+f = Expression("9.0*pi*pi*sin(3.0*pi*x[0])")
+g = Expression("3.0*pi*cos(3.0*pi*x[0])")
 
 a = dot(grad(v), grad(u))*dx
 L = v*f*dx + v*g*ds
 
 # Define boundary condition
-u0 = Constant(mesh, 0.0)
+u0 = Constant(0.0)
 bc = DirichletBC(V, u0, DirichletBoundary())
 
 # Solve PDE and plot solution
