@@ -19,9 +19,8 @@ __license__  = "GNU LGPL Version 2.1"
 # modified to work with SFC by Kent-Andre Mardal
 
 from dolfin import *
-dolfin_set("form compiler", "sfc")
+parameters["form_compiler"]["name"] = "sfc"
 
-#dolfin_set("linear algebra backend","Epetra")
 
 # Create mesh and define function space
 mesh = UnitSquare(32, 32)
@@ -33,15 +32,17 @@ class DirichletBoundary(SubDomain):
         return x[0] < DOLFIN_EPS or x[0] > 1.0 - DOLFIN_EPS
 
 # Define boundary condition
-u0 = Constant(mesh, 0.0)
+u0 = Constant(0.0)
 bc = DirichletBC(V, u0, DirichletBoundary())
 
 # Define variational problem
 v = TestFunction(V)
 u = TrialFunction(V)
-f = Function(V, "500.0 * exp(-(pow(x[0] - 0.5, 2) + pow(x[1] - 0.5, 2)) / 0.02)")
+f = Expression("500.0 * exp(-(pow(x[0] - 0.5, 2) + pow(x[1] - 0.5, 2)) / 0.02)")
+ff = Function(V)
+ff.interpolate(f)
 a = dot(grad(v), grad(u))*dx
-L = v*f*dx
+L = v*ff*dx
 
 # Compute solution
 problem = VariationalProblem(a, L, bc)
@@ -54,5 +55,7 @@ plot(u)
 file = File("poisson.pvd")
 file << u
 
+
+
 # Hold plot
 interactive()
