@@ -13,25 +13,19 @@
 using namespace dolfin;
 using namespace Projection;
 
-class Weight: public Function
+class Weight: public Expression 
 {
 public:
-  Weight(const FunctionSpace & V):
-    Function(V) {}
-
-  void eval(double* values, const double* x) const
+  void eval(Array<double>& values, const Array<double>& x) const
   {
     values[0] = 1.0;
   }
 };
 
-class Source: public Function
+class Source: public Expression 
 {
 public:
-  Source(const FunctionSpace & V):
-    Function(V) {}
-
-  void eval(double* values, const double* x) const
+  void eval(Array<double>& values, const Array<double>& x) const
   {
     double dx = x[0] - 0.5;
     double dy = x[1] - 0.5;
@@ -51,8 +45,8 @@ int main(int argc, char ** argv)
   CoefficientSpace_f F(mesh);
 
   // Functions
-  Weight c(C);
-  Source f(F);
+  Weight c;
+  Source f;
   Function u(V);
 
   // Forms
@@ -63,20 +57,14 @@ int main(int argc, char ** argv)
   a.c = c;
   L.f = f;
 
-  // Assemble linear system
-  Matrix A;
-  Vector b;
-  Assembler::assemble(A, a);
-  Assembler::assemble(b, L);
 
-  // Solve linear system
-  LUSolver solver(symmetric);
-  solver.solve(A, u.vector(), b);
+  VariationalProblem problem(a, L);
+  problem.solve(u);
 
   // Interpolate f onto the discrete space V
-  Source f2(V);
+  Source f2;
   Function fi(V);
-  f2.interpolate(fi.vector(), V);
+  fi = f2; 
 
   // Write u and f to file
   File u_file("u.pvd");
