@@ -12,25 +12,19 @@
 using namespace dolfin;
 using namespace Projection1D;
 
-class Weight: public Function
+class Weight: public Expression 
 {
 public:
-  Weight(const FunctionSpace & V):
-    Function(V) {}
-
-  void eval(double* values, const double* x) const
+  void eval(Array<double>& values, const Array<double>& x) const
   {
     values[0] = 1.0;
   }
 };
 
-class Source: public Function
+class Source: public Expression 
 {
 public:
-  Source(const FunctionSpace & V):
-    Function(V) {}
-
-  void eval(double* values, const double* x) const
+  void eval(Array<double>& values, const Array<double>& x) const
   {
     double dx = x[0] - 0.5;
     values[0] = dx*dx;
@@ -48,8 +42,8 @@ int main()
   CoefficientSpace_f F(mesh);
 
   // Functions
-  Weight c(C);
-  Source f(F);
+  Weight c;
+  Source f;
   Function u(V);
 
   // Forms
@@ -60,24 +54,17 @@ int main()
   a.c = c;
   L.f = f;
 
-  // Assemble linear system
-  Matrix A;
-  Vector b;
-  assemble(A, a);
-  assemble(b, L);
-
-  // Solve linear system
-  LUSolver solver;
-  solver.solve(A, u.vector(), b);
+  VariationalProblem problem(a, L);
+  problem.solve(u);
 
   // Write solution to file
   File u_file("u.pvd");
   u_file << u;
 
   // Interpolate f onto the discrete space V
-  Source source(V);
+  Source source;
   Function finterpolated(V);
-  source.interpolate(finterpolated.vector(), V);
+  finterpolated = source; 
 
   // Write interpolated solution to file
   File f_file("f.pvd");
