@@ -1,7 +1,10 @@
 
 from dolfin import *
+parameters["form_compiler"]["name"] = "sfc"
 
-class Source(Function): 
+class Source(Expression): 
+    def rank(self): return 2
+    def dim(sel): return (2,2)
     def eval(self, values, x): 
         values[0] = x[0]
         values[1] = x[1]
