@@ -13,9 +13,10 @@ from ufl import *
 
 # Options handling
 from sfc.common import version
-from sfc.common import default_options
+from sfc.common import default_options as default_parameters
 from sfc.common import set_logging_level
 
+
 # Function for compiling a UFL element into UFC code
 #from compiler import compile_element # Merge with jit if we want it.
 
@@ -23,7 +24,7 @@ from sfc.common import set_logging_level
 #from compiler import compile_form
 
 # Function for compiling a form and importing it on the fly
-from sfc.jit import generate_code, cache_signature, jit
+from sfc.jit import generate_code, cache_signature, jit, jitf
 
 __version__ = "0.6.1"
 __author__ = "Martin Sandve Alnæs"
