@@ -108,16 +108,16 @@ class CodeFormatter:
         self.assert_context(context)
         c = self.context.pop(-1)
         if not c == context:
-            raise RuntimeError, "Expected context '%s' to be '%s'." % (c, context)
+            raise RuntimeError("Expected context '%s' to be '%s'." % (c, context))
     
     def assert_context(self, context):
         if not (self.context[-1] == context):
-            raise RuntimeError, "Expected to be in context '%s', state is %s." % (context, str(self.context))
+            raise RuntimeError("Expected to be in context '%s', state is %s." % (context, str(self.context)))
     
     def assert_contexts(self, contexts):
         for i in range(len(contexts)):
             if not self.context[-(i+1)] == contexts[i]:
-                raise RuntimeError, "Expected to be in contexts %s, state is %s." % (str(contexts), str(self.context))
+                raise RuntimeError("Expected to be in contexts %s, state is %s." % (str(contexts), str(self.context)))
     
     def assert_closed_code(self):
         self.assert_context("ROOT")
@@ -295,7 +295,7 @@ def row_major_index_string(i, shape):
         return "%d" % i[0]
     if len(shape) == 2:
         return "%d*%d + %d" % (shape[1], i[0], i[1])
-    raise "Rank 3 or higher not supported in row_major_index_string()"
+    raise ValueError("Rank 3 or higher not supported in row_major_index_string()")
 
 
 def optimize_floats(code):
