@@ -21,5 +21,5 @@ def gen_utility_code(hfilename):
        return name, DofT.header, DofT.implementation
     if name == "Dof_Ptv":
        return name, Dof_Ptv.header, Dof_Ptv.implementation
-    raise RuntimeError, "Unknown utility '%s'." % hfilename
+    raise RuntimeError("Unknown utility '%s'." % hfilename)
 
