@@ -11,6 +11,7 @@ __date__   = "2008-08-13 -- 2008-12-16"
 __copyright__ = "(C) 2008 Martin Sandve Alnes and Simula Resarch Laboratory"
 __license__  = "GNU GPL Version 2, or (at your option) any later version"
 
+# Modified by Kent-Andre Mardal 2010 
 
 import operator
 import ufl
@@ -45,17 +46,21 @@ def create_syfi_polygon(cell):
     elif cell == "tetrahedron":    p = SyFi.ReferenceTetrahedron()
     elif cell == "quadrilateral":  p = SyFi.ReferenceRectangle()
     elif cell == "hexahedron":     p = SyFi.ReferenceBox()
-    else: raise "Unknown element cell '%s'." % cell
+    else: raise ValueError("Unknown element cell '%s'." % cell)
     sfc_debug("Leaving create_syfi_polygon")
     return p
 
-def create_syfi_element(e, polygon):
+def create_syfi_element(e, polygon, default_order=1):
     "Create a basic element with SyFi."
     sfc_debug("Entering create_syfi_element")
     
     sfc_assert(not isinstance(e, ufl.MixedElement), "Only creating SyFi elements for basic elements.")
     f = e.family()
+
+    # ensure that the element always have some degree, this should probably be  
     d = e.degree()
+    if not isinstance(d, int): d = default_order 
+
     if   f in ("Lagrange", "CG"):
         fe = SyFi.Lagrange(polygon, d)
     elif f in ("Discontinuous Lagrange", "DG"):
@@ -66,25 +71,25 @@ def create_syfi_element(e, polygon):
     elif f in ("Bubble", "B"):
         fe = SyFi.Bubble(polygon, d)
     elif f in ("Brezzi-Douglas-Marini", "BDM"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Brezzi-Douglas-Fortin-Marini", "BDFM"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Raviart-Thomas", "RT"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Nedelec 1st kind H(div)", "N1div"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Nedelec 2nd kind H(div)", "N2div"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Nedelec 1st kind H(curl)", "N1curl"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Nedelec 2nd kind H(curl)", "N2curl"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Quadrature", "Q"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     elif f in ("Boundary Quadrature", "BQ"):
-        raise NotImplementedError, "Not implemented element family '%s'." % f
+        raise NotImplementedError("Not implemented element family '%s'." % f)
     else:
-        raise NotImplementedError, "Unknown element family '%s'." % f
+        raise NotImplementedError("Unknown element family '%s'." % f)
     
     sfc_debug("Leaving create_syfi_element")
     return fe
@@ -129,7 +134,7 @@ class ElementRepresentation(object):
                  # Geometry symbols:
                  "p0", "p", "G", "GinvT",
                  )
-    def __init__(self, ufl_element, quad_rule=None, options=None, cache=None):
+    def __init__(self, ufl_element, quad_rule=None, options=None, cache=None, common_cell=None):
         sfc_debug("Entering ElementRepresentation.__init__")
         
         # Handle input and default values
@@ -150,6 +155,12 @@ class ElementRepresentation(object):
         
         # Geometry information
         self.ufl_cell = self.ufl_element.cell()
+        
+        # make sure that the element has a cell in case of Expressions etc.  
+        if common_cell: 
+            self.ufl_element.set_cell(common_cell)
+
+        self.ufl_cell = self.ufl_element.cell()
         self.polygon = create_syfi_polygon(self.ufl_cell.domain())
         self.cell = UFCCell(self.polygon)
         
@@ -207,7 +218,7 @@ class ElementRepresentation(object):
         
         else:
             # Make SyFi element
-            self.syfi_element = create_syfi_element(self.ufl_element, self.polygon)
+            self.syfi_element = create_syfi_element(self.ufl_element, self.polygon, default_order=options.code.finite_element.default_order_of_element)
             self.local_dimension = self.syfi_element.nbf()
         
         # utility symbols
