@@ -39,9 +39,9 @@ class FormRepresentation(object):
         self.options   = options
         
         # Fetch some common variables from formdata for shorter names in rest of code
-        self.form             = self.formdata.form
+        self.form             = self.formdata._form
         self.rank             = self.formdata.rank
-        self.num_coefficients = self.formdata.num_functions
+        self.num_coefficients = self.formdata.num_coefficients
         self.domain           = self.formdata.cell.domain()
         
         # Some strings
