@@ -8,6 +8,8 @@ __date__   = "2008-08-13 -- 2009-03-12"
 __copyright__ = "(C) 2008-2009 Martin Sandve Alnes and Simula Resarch Laboratory"
 __license__  = "GNU GPL Version 2, or (at your option) any later version"
 
+# Modified by Kent-Andre Mardal 2010 
+
 from itertools import izip
 
 #import SyFi
@@ -316,7 +318,7 @@ class IntegralRepresentation(object):
                         print "Failed to fetch expression for vertex %d," % j
                         print "    V[%d] = %s" % (j, repr(V[j]))
                         print "    parent V[%d] = %s" % (i, repr(V[i]))
-                        raise
+                        raise RuntimeError
                     ops.append(e)
                 ops = tuple(ops)
                 e = data.evaluate(v, *ops)
